bayespy.inference.vmp.transformations.RotationOptimizer
=======================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. autoclass:: RotationOptimizer

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~RotationOptimizer.__init__
      ~RotationOptimizer.rotate
   
   

   
   
   